summaryrefslogtreecommitdiff
path: root/src/expr/expr_manager_template.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/expr/expr_manager_template.h')
-rw-r--r--src/expr/expr_manager_template.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/expr/expr_manager_template.h b/src/expr/expr_manager_template.h
index 8e02c8ca4..316a9b7b1 100644
--- a/src/expr/expr_manager_template.h
+++ b/src/expr/expr_manager_template.h
@@ -224,11 +224,11 @@ public:
/** Make the type of arrays with the given parameterization */
ArrayType mkArrayType(Type indexType, Type constituentType) const;
- /** Make a new sort with the given name. */
- SortType mkSort(const std::string& name) const;
+ /** Make a new sort with the given name and arity. */
+ SortType mkSort(const std::string& name, size_t arity = 0) const;
/** Get the type of an expression */
- Type getType(const Expr& e, bool check = false)
+ Type getType(const Expr& e, bool check = false)
throw (TypeCheckingException);
// variables are special, because duplicates are permitted
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback